define('dojo/nls/pmbdijit_pt-br',{
'dijit/nls/loading':{"loadingState":"Carregando...","errorState":"Desculpe, ocorreu um erro","_localized":{}}
,
'dijit/form/nls/validate':{"invalidMessage":"O valor inserido não é válido.","missingMessage":"Este valor é necessário.","rangeMessage":"Este valor está fora do intervalo. ","_localized":{}}
,
'dojo/cldr/nls/number':{"scientificFormat":"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]","infinity":"∞","superscriptingExponent":"×","list":";","percentSign":"%","minusSign":"-","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000 tri","currencySpacing-afterCurrency-insertBetween":" ","nan":"NaN","plusSign":"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]","currencyFormat":"¤#,##0.00;(¤#,##0.00)","perMille":"‰","group":".","percentFormat":"#,##0%","decimalFormat-long":"000 trilhões","decimalFormat":"#,##0.###","decimal":",","currencySpacing-beforeCurrency-insertBetween":" ","exponential":"E","_localized":{}}
,
'dijit/nls/common':{"buttonOk":"OK","buttonCancel":"Cancelar","buttonSave":"Salvar","itemClose":"Fechar","_localized":{}}
,
'dijit/_editor/nls/commands':{"bold":"Negrito","copy":"Copiar","cut":"Recortar","delete":"Excluir","indent":"Recuar","insertHorizontalRule":"Régua Horizontal","insertOrderedList":"Lista Numerada","insertUnorderedList":"Lista com Marcadores","italic":"Itálico","justifyCenter":"Alinhar pelo Centro","justifyFull":"Justificar","justifyLeft":"Alinhar pela Esquerda","justifyRight":"Alinhar pela Direita","outdent":"Não-chanfrado","paste":"Colar","redo":"Refazer","removeFormat":"Remover Formato","selectAll":"Selecionar Todos","strikethrough":"Tachado","subscript":"Subscrito","superscript":"Sobrescrito","underline":"Sublinhado","undo":"Desfazer","unlink":"Remover Link","createLink":"Criar Link","toggleDir":"Comutar Direção","insertImage":"Inserir Imagem","insertTable":"Inserir/Editar Tabela","toggleTableBorder":"Alternar Moldura da Tabela","deleteTable":"Excluir Tabela","tableProp":"Propriedade da Tabela","htmlToggle":"Origem HTML","foreColor":"Cor do Primeiro Plano","hiliteColor":"Cor de segundo plano","plainFormatBlock":"Estilo de Parágrafo","formatBlock":"Estilo de Parágrafo","fontSize":"Tamanho da Fonte","fontName":"Nome da Fonte","tabIndent":"Recuo de Guia","fullScreen":"Comutar Tela Cheia","viewSource":"Visualizar Origem HTML","print":"Impressão","newPage":"Nova Página","systemShortcut":"A ação \"${0}\" está disponível em seu navegador apenas usando um atalho do teclado. Use ${1}.","ctrlKey":"ctrl+${0}","appleKey":"⌘${0}","_localized":{}}
,
'dijit/form/nls/ComboBox':{"previousMessage":"Opções anteriores","nextMessage":"Mais opções","_localized":{}}
,
'dijit/_editor/nls/FontChoice':{"1":"extra-extra-pequeno","2":"extra-pequeno","3":"pequena","4":"médio","5":"grande","6":"extra-grande","7":"extra-extra-grande","fontSize":"Tamanho","fontName":"Fonte","formatBlock":"Formatar","serif":"serif","sans-serif":"sans-serif","monospace":"espaço simples","cursive":"cursiva","fantasy":"fantasy","noFormat":"Nenhum","p":"Parágrafo","h1":"Título","h2":"Subtítulo","h3":"Sub-subtítulo","pre":"Pré-formatado","_localized":{}}
,
'dojox/editor/plugins/nls/latinEntities':{"iexcl":"ponto de exclamação invertido","cent":"símbolo de centavo","pound":"símbolo de libra","curren":"símbolo de moeda","yen":"símbolo de ienesímbolo de yuan","brvbar":"barra interrompida\nbarra vertical interrompida","sect":"símbolo de seção","uml":"trema\ntrema de espaçamento","copy":"símbolo de copyright","ordf":"indicador ordinal feminino","laquo":"aspas latinas duplas de encerramento\nsímbolo de citação esquerdo","not":"nenhum símbolo","shy":"hífen reformatável\nhífen discricionário","reg":"símbolo de marca registrada\nsímbolo de marca comercial registrada","macr":"macro\nmacro de espaçamento\nsobrelinha\nsobrebarra APL","deg":"símbolo de grau","plusmn":"símbolo de mais e menos\nsímbolo de mais ou menos","sup2":"sobrescrito dois\ndígito sobrescrito dois\nquadrado","sup3":"sobrescrito três\ndígito sobrescrito três\nem cubo","acute":"acento agudo\nagudo para espaçamento","micro":"símbolo de micro","para":"símbolo pé-de-mosca\nsímbolo de parágrafo","middot":"ponto do meio\nvírgula Georgiana\nponto do meio grego","cedil":"cedilha\ncedilha de espaçamento","sup1":"sobrescrito um\ndígito sobrescrito um","ordm":"indicador ordinal masculino","raquo":"aspas latinas duplas de abertura\nsímbolo de citação direito","frac14":"fração de um quarto comum\nfração de um quarto","frac12":"fração de um meio comum\nfração de um meio","frac34":"fração de três quartos comum\nfração de três quartos","iquest":"ponto de interrogação invertido\nponto de interrogação invertido","Agrave":"Letra latina maiúscula A com acento grave\nletra latina maiúscula A com acento grave","Aacute":"Letra latina maiúscula A com acento agudo","Acirc":"Letra latina maiúscula A com acento circunflexo","Atilde":"Letra latina maiúscula A com til","Auml":"Letra latina maiúscula A com trema","Aring":"Letra latina maiúscula A com círculo em cima\nLetra latina maiúscula A com círculo","AElig":"Letra latina maiúscula AE\nLetra latina maiúscula AE","Ccedil":"Letra latina maiúscula C com cedilha","Egrave":"Letra latina maiúscula E com acento grave","Eacute":"Letra latina maiúscula E com acento agudo","Ecirc":"Letra latina maiúscula E com acento circunflexo","Euml":"Letra latina maiúscula E com trema","Igrave":"Letra latina maiúscula I com acento grave","Iacute":"Letra latina maiúscula I com acento agudo","Icirc":"Letra latina maiúscula I com acento circunflexo","Iuml":"Letra latina maiúscula I com trema","ETH":"Letra latina maiúscula ETH","Ntilde":"Letra latina maiúscula N com til","Ograve":"Letra latina maiúscula O com acento grave","Oacute":"Letra latina maiúscula O com acento agudo","Ocirc":"Letra latina maiúscula O com acento circunflexo","Otilde":"Letra latina maiúscula O com til","Ouml":"Letra latina maiúscula O com trema","times":"símbolo de multiplicação","Oslash":"Letra latina maiúscula O traçada\nLetra latina maiúscula O cortada com barra","Ugrave":"Letra latina maiúscula U com acento grave","Uacute":"Letra latina maiúscula U com acento agudo","Ucirc":"Letra latina maiúscula U com acento circunflexo","Uuml":"Letra latina maiúscula U com trema","Yacute":"Letra latina maiúscula Y com acento agudo","THORN":"Letra latina maiúscula THORN","szlig":"Letra latina minúscula scharfes s\ness-zed","agrave":"Letra latina minúscula a com acento grave\nletra latina minúscula a com acento grave","aacute":"Letra latina minúscula a com acento agudo","acirc":"Letra latina minúscula a com acento circunflexo","atilde":"Letra latina minúscula a com til","auml":"Letra latina minúscula a com trema","aring":"Letra latina minúscula a com círculo em cima\nLetra latina minúscula a com círculo","aelig":"Letra latina minúscula ae\nLetra latina minúscula ae contraída","ccedil":"Letra latina minúscula c com cedilha","egrave":"Letra latina minúscula e com acento grave","eacute":"Letra latina minúscula e com acento agudo","ecirc":"Letra latina minúscula e com acento circunflexo","euml":"Letra latina minúscula e com trema","igrave":"Letra latina minúscula i com acento grave","iacute":"Letra latina minúscula i com acento agudo","icirc":"Letra latina minúscula i com acento circunflexo","iuml":"Letra latina minúscula i com trema","eth":"Letra latina minúscula eth","ntilde":"Letra latina minúscula n com til","ograve":"Letra latina minúscula o com acento grave","oacute":"Letra latina minúscula o com acento agudo","ocirc":"Letra latina minúscula o com acento circunflexo","otilde":"Letra latina minúscula o com til","ouml":"Letra latina minúscula o com trema","divide":"símbolo de divisão","oslash":"Letra latina minúscula o traçada\nLetra latina minúscula o cortada com barra","ugrave":"Letra latina minúscula u com acento grave","uacute":"Letra latina minúscula u com acento agudo","ucirc":"Letra latina minúscula u com acento circunflexo","uuml":"Letra latina minúscula u com trema","yacute":"Letra latina minúscula y com acento agudo","thorn":"Letra latina minúscula thorn","yuml":"Letra latina minúscula y com trema","fnof":"Letra latina minúscula f com gancho\nfunção\nflorim","Alpha":"Letra grega maiúscula alfa","Beta":"Letra grega maiúscula beta","Gamma":"Letra grega maiúscula gama","Delta":"Letra grega maiúscula delta","Epsilon":"Letra grega maiúscula épsilon","Zeta":"Letra grega maiúscula zeta","Eta":"Letra grega maiúscula eta","Theta":"Letra grega maiúscula teta","Iota":"Letra grega maiúscula iota","Kappa":"Letra grega maiúscula capa","Lambda":"Letra grega maiúscula lambda","Mu":"Letra grega maiúscula miu","Nu":"Letra grega maiúscula nu","Xi":"Letra grega maiúscula ksi","Omicron":"Letra grega maiúscula ómicron","Pi":"Letra grega maiúscula pi","Rho":"Letra grega maiúscula rô","Sigma":"Letra grega maiúscula sigma","Tau":"Letra grega maiúscula tau","Upsilon":"Letra grega maiúscula upsilon","Phi":"Letra grega maiúscula fi","Chi":"Letra grega maiúscula chi","Psi":"Letra grega maiúscula psi","Omega":"Letra grega maiúscula ômega","alpha":"Letra grega minúscula alfa","beta":"Letra grega minúscula beta","gamma":"Letra grega minúscula gama","delta":"Letra grega minúscula delta","epsilon":"Letra grega minúscula épsilon","zeta":"Letra grega minúscula zeta","eta":"Letra grega minúscula eta","theta":"Letra grega minúscula teta","iota":"Letra grega minúscula iota","kappa":"Letra grega minúscula capa","lambda":"Letra grega minúscula lambda","mu":"Letra grega minúscula miu","nu":"Letra grega minúscula nu","xi":"Letra grega minúscula ksi","omicron":"Letra grega minúscula ómicron","pi":"Letra grega minúscula pi","rho":"Letra grega minúscula rô","sigmaf":"Letra grega minúscula sigma final","sigma":"Letra grega minúscula sigma","tau":"Letra grega minúscula tau","upsilon":"Letra grega minúscula upsilon","phi":"Letra grega minúscula fi","chi":"Letra grega minúscula chi","psi":"Letra grega minúscula psi","omega":"Letra grega minúscula ômega","thetasym":"Símbolo da letra grega minúscula teta","upsih":"Símbolo da letra grega upsilon com gancho","piv":"Símbolo grego pi","bull":"marcador\npequeno círculo preto","hellip":"reticências horizontais\ntrês pontos","prime":"primário\nminutos\npés","Prime":"primário duplo\nsegundos\npolegadas","oline":"sobrelinha\nlinha sobreposta de espaçamento","frasl":"barra de fração","weierp":"script com letra P maiúscula\nconjunto de potências\nWeierstrass p","image":"letra I maiúscula gótica\nparte imaginária","real":"letra R maiúscula gótica\nsímbolo da parte real","trade":"símbolo de marca registrada","alefsym":"símbolo alef\nprimeiro cardinal transfinito","larr":"seta para esquerda","uarr":"seta para cima","rarr":"seta para direita","darr":"seta para baixo","harr":"seta para esquerda e direita","crarr":"seta para baixo com curva para esquerda\nretorno de texto","lArr":"seta dupla para esquerda","uArr":"seta dupla para cima","rArr":"seta dupla para direita","dArr":"seta dupla para baixo","hArr":"seta dupla para esquerda e direita","forall":"para todos","part":"diferença parcial","exist":"existe pelo menos","empty":"conjunto vazio\nconjunto nulo\ndiâmetro","nabla":"nabla\ndiferença de retrógrado","isin":"pertence a","notin":"não pertence a","ni":"contém","prod":"produto n-ary\nsinal de produto","sum":"somatório de n elementos","minus":"sinal de menos","lowast":"asterisco","radic":"raiz quadrada\nsinal de radical","prop":"proporcional a","infin":"infinito","ang":"ângulo","and":"lógica e\nforça","or":"lógica ou\nvee","cap":"limite de\nintersecção","cup":"união\ncopa","int":"integral","there4":"para isso","sim":"operador de til\nvaria com\nsemelhante a","cong":"aproximadamente igual a","asymp":"quase igual a\nassintótico a","ne":"diferente de","equiv":"idêntico a","le":"menor ou igual a","ge":"maior ou igual a","sub":"está contido em","sup":"contém","nsub":"não está contido em","sube":"está contido ou é igual a","supe":"contém ou é igual a","oplus":"circulado mais\nsoma direta","otimes":"vezes circulado\nproduto de vetor","perp":"desvio para cima\nortogonal para\nperpendicular","sdot":"ponto de multiplicação","lceil":"teto esquerdo\nlance vertical APL","rceil":"chave em L com o canto voltado para cima à direita","lfloor":"piso esquerdo\nlance para baixo APL","rfloor":"chave em L com o canto voltado para baixo à direita","lang":"sinal de maior e menor para esquerda","rang":"sinal de maior e menor para direita","loz":"losango","spades":"símbolo de espadas","clubs":"símbolo de\npaustrevo","hearts":"coração negro\nsímbolo de copas","diams":"diamante negro","OElig":"Ligação latina maiúscula OE","oelig":"Ligação latina minúscula oe","Scaron":"Letra latina maiúscula S com caron","scaron":"Letra latina minúscula s com caron","Yuml":"Letra latina maiúscula Y com trema","circ":"Acento circunflexo","tilde":"til pequeno","ensp":"espaço simples","emsp":"espaço duplo","thinsp":"espaço estreito","zwnj":"separador de largura zero","zwj":"conector de largura zero","lrm":"marca da esquerda para a direita","rlm":"marca da direita para a esquerda","ndash":"traço","mdash":"travessão","lsquo":"aspas simples à esquerda","rsquo":"aspas simples à direita","sbquo":"aspas simples inferior à direita","ldquo":"aspas duplas inferior à esquerda","rdquo":"aspas duplas à direita","bdquo":"aspas duplas inferiores à direita","dagger":"cruz","Dagger":"cruz dupla","permil":"símbolo por mil","lsaquo":"aspa latina de encerramento","rsaquo":"aspa latina de abertura","euro":"símbolo de euro","_localized":{}}
,
'dojox/editor/plugins/nls/InsertEntity':{"insertEntity":"Inserir Símbolo","_localized":{}}
,
'dojo/nls/colors':{"aliceblue":"azul alice","antiquewhite":"branco antigo","aqua":"aqua","aquamarine":"água marinha","azure":"azul celeste","beige":"bege","bisque":"bisque","black":"preto","blanchedalmond":"amêndoa pelada","blue":"azul","blueviolet":"azul violeta","brown":"marrom","burlywood":"burlywood","cadetblue":"azul cadet","chartreuse":"chartreuse","chocolate":"chocolate","coral":"coral","cornflowerblue":"azul centaurea","cornsilk":"cornsilk","crimson":"carmesim","cyan":"ciano","darkblue":"azul escuro","darkcyan":"ciano escuro","darkgoldenrod":"goldenrod escuro","darkgray":"cinza escuro","darkgreen":"verde escuro","darkgrey":"cinza escuro","darkkhaki":"cáqui escuro","darkmagenta":"magenta escuro","darkolivegreen":"verde oliva escuro","darkorange":"laranja escuro","darkorchid":"orquídea escuro","darkred":"vermelho escuro","darksalmon":"salmão escuro","darkseagreen":"verde marinho escuro","darkslateblue":"azul ardósia escuro","darkslategray":"cinza ardósia escuro","darkslategrey":"cinza ardósia escuro","darkturquoise":"turquesa escuro","darkviolet":"violeta escuro","deeppink":"rosa profundo","deepskyblue":"azul céu intenso","dimgray":"cinza turvo","dimgrey":"cinza turvo","dodgerblue":"azul dodger","firebrick":"firebrick","floralwhite":"branco floral","forestgreen":"verde floresta","fuchsia":"fúcsia","gainsboro":"gainsboro","ghostwhite":"branco ghost","gold":"dourado","goldenrod":"goldenrod","gray":"cinza","green":"verde","greenyellow":"amarelo esverdeado","grey":"cinza","honeydew":"honeydew","hotpink":"rosa quente","indianred":"vermelho indiano","indigo":"índigo","ivory":"marfim","khaki":"cáqui","lavender":"lavanda","lavenderblush":"lavanda avermelhada","lawngreen":"verde grama","lemonchiffon":"limão chiffon","lightblue":"azul claro","lightcoral":"coral claro","lightcyan":"ciano claro","lightgoldenrodyellow":"amarelo goldenrod claro","lightgray":"cinza claro","lightgreen":"verde claro","lightgrey":"cinza claro","lightpink":"rosa claro","lightsalmon":"salmão claro","lightseagreen":"verde marinho claro","lightskyblue":"azul céu claro","lightslategray":"cinza ardósia claro","lightslategrey":"cinza ardósia claro","lightsteelblue":"azul aço claro","lightyellow":"amarelo claro","lime":"lima","limegreen":"verde lima","linen":"linho","magenta":"magenta","maroon":"castanho","mediumaquamarine":"água marinha médio","mediumblue":"azul médio","mediumorchid":"orquídea médio","mediumpurple":"roxo médio","mediumseagreen":"verde marinho médio","mediumslateblue":"azul ardósia médio","mediumspringgreen":"verde primavera médio","mediumturquoise":"turquesa médio","mediumvioletred":"vermelho violeta médio","midnightblue":"azul meia-noite","mintcream":"creme de menta","mistyrose":"rosa enevoado","moccasin":"moccasin","navajowhite":"branco navajo","navy":"marinho","oldlace":"cadarço velho","olive":"oliva","olivedrab":"verde oliva","orange":"laranja","orangered":"vermelho alaranjado","orchid":"orquídea","palegoldenrod":"goldenrod esbranquiçado","palegreen":"verde esbranquiçado","paleturquoise":"turquesa esbranquiçado","palevioletred":"vermelho violeta esbranquiçado","papayawhip":"creme de papaya","peachpuff":"peach puff","peru":"peru","pink":"rosa","plum":"ameixa","powderblue":"azul talco","purple":"roxo","red":"vermelho","rosybrown":"marrom rosado","royalblue":"azul royal","saddlebrown":"marrom saddle","salmon":"salmão","sandybrown":"marrom cor de areia","seagreen":"verde marinho","seashell":"seashell","sienna":"sienna","silver":"prateado","skyblue":"azul céu","slateblue":"azul ardósia","slategray":"cinza ardósia","slategrey":"cinza ardósia","snow":"branco neve","springgreen":"verde primavera","steelblue":"azul aço","tan":"tan","teal":"azul esverdeado","thistle":"thistle","tomato":"tomate","transparent":"transparente","turquoise":"turquesa","violet":"violeta","wheat":"trigo","white":"branco","whitesmoke":"fumaça branca","yellow":"amarelo","yellowgreen":"verde amarelado","_localized":{}}
,
'dojox/widget/nls/ColorPicker':{"redLabel":"r","greenLabel":"g","blueLabel":"b","hueLabel":"h","saturationLabel":"s","valueLabel":"v","degLabel":"°","hexLabel":"hex","huePickerTitle":"Seletor de Matiz","saturationPickerTitle":"Seletor de Saturação","_localized":{}}
,
'dojox/editor/plugins/nls/TableDialog':{"insertTableTitle":"Inserir Tabela","modifyTableTitle":"Modificar Tabela","rows":"Linhas:","columns":"Colunas:","align":"Alinhar:","cellPadding":"Preenchimento de Célula:","cellSpacing":"Espaçamento de Célula:","tableWidth":"Largura da Tabela:","backgroundColor":"Cor do Plano de Fundo:","borderColor":"Cor da Borda:","borderThickness":"Espessura da Borda:","percent":"percentual","pixels":"pixels","default":"default","left":"esquerda","center":"centro","right":"direita","buttonSet":"Configurar","buttonInsert":"Inserir","buttonCancel":"Cancelar","selectTableLabel":"Selecionar Tabela","insertTableRowBeforeLabel":"Incluir Linha Antes","insertTableRowAfterLabel":"Incluir Linha Depois","insertTableColumnBeforeLabel":"Incluir Coluna Antes","insertTableColumnAfterLabel":"Incluir Coluna Depois","deleteTableRowLabel":"Excluir Linha","deleteTableColumnLabel":"Excluir Coluna","colorTableCellTitle":"Célula de Tabela de Cor do Segundo Plano","tableContextMenuTitle":"Menu de Contexto da Tabela","_localized":{}}
,
'dojox/editor/plugins/nls/PasteFromWord':{"pasteFromWord":"Colar do Word","instructions":"Cole o conteúdo do Word na caixa de texto a seguir. Quando estiver satisfeito com o conteúdo a ser inserido, pressione o botão para colar. Para interromper a inserção de texto, pressione o botão para cancelar.","_localized":{}}
,
'dojox/editor/plugins/nls/InsertAnchor':{"insertAnchor":"Inserir Âncora","title":"Propriedades de Âncora","anchor":"Nome:","text":"Descrição:","set":"Configurar","cancel":"Cancelar","_localized":{}}
,
'dojox/editor/plugins/nls/Blockquote':{"blockquote":"Citação de Bloco","_localized":{}}
,
'dojox/editor/plugins/nls/LocalImage':{"insertImageTitle":"Inserir imagem","url":"Imagem","browse":"Procurar...","text":"Descrição","set":"Inserir","invalidMessage":"Tipo de arquivo de imagem inválido","prePopuTextUrl":"Insira uma URL de imagem","prePopuTextBrowse":" ou navegue até um arquivo local.","_localized":{}}
});